# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-06 06:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course_simple', '0028_userquestion_is_correct'),
    ]

    operations = [
        migrations.AddField(
            model_name='part',
            name='award_name',
            field=models.CharField(blank=True, help_text='\u4ec5\u5728\u5c0f\u8282\u7c7b\u578b\u4e3a\u95ee\u9898\uff0c\u4e14\u6709\u6b63\u786e\u7b54\u6848\u65f6\u663e\u793a', max_length=180, null=True, verbose_name='\u5956\u54c1\u540d\u79f0'),
        ),
        migrations.AddField(
            model_name='part',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u8bf4\u660e'),
        ),
        migrations.AlterField(
            model_name='question',
            name='tip_correct',
            field=models.TextField(blank=True, null=True, verbose_name='\u6b63\u786e\u65f6\u63d0\u793a\u8bcd'),
        ),
        migrations.AlterField(
            model_name='question',
            name='tip_wrong',
            field=models.TextField(blank=True, null=True, verbose_name='\u9519\u8bef\u65f6\u63d0\u793a\u8bcd'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'


from django.conf import settings

class Gensee():
    pass

class CC():
    pass

class Qiniu():
    ak='w4yaDe9SPuChxJHBQnefqlond1704XS4vHU_3sMK'
    sk='stoLiR-4tCV7v0A51S-ly4fFJgNWI_b0USdQccua'
    bucket_name='xinanxiangju-video'
    domain='video.xinanxiangju.com'

class Tencent():
    pass



# ======初始化========
# cc
if "cc" in settings.COURSE_LIVE_PROVIDER_LIST or "cc" == settings.COURSE_VIDEO_PROVIDER_NAME:
    settings.CC_CONFIG=CC()
#
# qiniu
if "qiniu" == settings.COURSE_VIDEO_PROVIDER_NAME:
    settings.QINIU_CONFIG=Qiniu()
#
# gensee
if "gensee" in settings.COURSE_LIVE_PROVIDER_LIST:
    settings.GENSEE_CONFIG=Gensee()

if "tencent" in settings.COURSE_LIVE_PROVIDER_LIST:
    settings.TENCENT_CONFIG=Tencent()
    pass
